<?php

namespace App\Http\Controllers;

use App\Social_Network;
use Illuminate\Http\Request;
use App\User;
//use Illuminate\Support\Facades\Auth;
use Auth;
use Illuminate\Support\Facades\Date;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Carbon;


class ProfilController extends Controller
{

    /**
     * Create a new controller instance.
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user_id = auth()->user()->id;
        $socialNetworks = Social_Network::find($user_id);

        $user = User::find($user_id);
        if($user->birthday){
            $myage =  Carbon::parse($user->birthday)->age;
        }else{
            $myage = null;
        }

        if (auth()->user()->hasPermissionTo('access dashboard')){
            return view('profils.index', compact('socialNetworks', 'myage'));
        }
        return view('profile', compact('socialNetworks', 'myage'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    public function updateProfil(Request $request)
    {
        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email',
            'nationality' => 'required',
            'phone' => 'required',
            'address' => 'required|max:250',
        ]);

        $user_id = auth()->user()->id;
        $user = User::find($user_id);

        $name = $request->input('name');
        $firstname = $request->input('firstname');
        $email = $request->input('email');
        $phone = $request->input('phone');
        $address = $request->input('address');
        $nationality = $request->input('nationality');

        User::where('id', $user_id)
            ->update([
                    'name' => $name,
                    'firstname' => $firstname,
                    'email' => $email,
                    'phone' => $phone,
                    'address' => $address,
                    'nationality' => $nationality,
                ]);

        return redirect('myprofil')->with('success', 'Profil mis à jour');

    }


    public function updateProfil2(Request $request)
    {
        //Validate name, email and password fields
        $this->validate($request, [
            'birthday' => 'required|date|before:today',
            'gender' => 'required',
            'mensuration' => 'required|integer',
            'height' => 'required',
            'job' => 'required',
        ]);

        $user_id = auth()->user()->id;
        $user = User::find($user_id);


        $birthday = $request->input('birthday');
        $gender = $request->input('gender');
        $mensuration = $request->input('mensuration');
        $height = $request->input('height');
        $job = $request->input('job');

        User::where('id', $user_id)
            ->update([
                    'birthday' => $birthday,
                    'gender' => $gender,
                    'mensuration' => $mensuration,
                    'height' => $height,
                    'job' => $job,
                ]);

        return redirect('myprofil')->with('success', 'Profil mis à jour');

    }


    public function profilImageUpdate(Request $request){

        $this->validate($request, [
            'profilImage' => 'image|nullable',
        ]);

        if ($request->hasfile('profilImage')) {
            $image = $this->storeImage($request->file('profilImage'));
            $user_id = auth()->user()->id;

            User::where('id', $user_id)
                ->update([
                        'profilImage' => $image,
                    ]);
        }else{
            return redirect('myprofil')->with('errors', 'Veuillez selectionner une image de profil pour la modification');
        }

        return redirect('myprofil')->with('success', 'Image de Profile modifier avec succes');

    }

    public function coverImageUpdate(Request $request){

        $this->validate($request, [
            'coverImage' => 'image|nullable',
        ]);

        if ($request->hasfile('coverImage')) {
            $image = $this->storeImage($request->file('coverImage'));
            $user_id = auth()->user()->id;

            User::where('id', $user_id)
                ->update([
                        'coverImage' => $image,
                    ]);
        }else{
            return redirect('myprofil')->with('errors', 'Veuillez selectionner une image de couverture pour la modification');
        }

        return redirect('myprofil')->with('success', 'Image de couverture modifier avec succes');

    }


    public function passwordupdate(Request $request){

        //Validate password fields
        $this->validate($request, [
            'password' => 'required|min:12|confirmed',
        ]);

        $user_id = auth()->user()->id;
        $user = User::findOrFail($user_id); //Get user specified by id

        $user->password = $request->input('password');
        $user->save();

        return redirect('myprofil')->with('success', 'Votre mot de passe a été changé');

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $user = User::findOrFail(decrypt($id));
        $socialNetworks = Social_Network::findOrFail(decrypt($id));

        if($user->birthday){
            $myage =  Carbon::parse($user->birthday)->age;
        }else{
            $myage = null;
        }

        return view('member', compact('user', 'socialNetworks', 'myage'));
    }



    public function showMembers(){

        $i = 0;
        $ids = [];
        $users = User::all();

        foreach($users as $i => $user){

            if( $user->roles()->pluck('name')->implode(' ') == 'member' ){
                //dd($user);
                //$ids = implode(',', $user->id);
                //$ids = collect($user->id);
                $ids[$i] = $user->id;
                $i++;
            }

        }

        //dd($ids);

        $members = User::whereIn('id', $ids)->get();

        dd($members);

    }

    public function members(){
        $members = User::where('roleId', '=', 2)->get();

        return view('members', compact('members'));
    }
    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit()
    {
        $user_id = auth()->user()->id;
        $socialNetworks = Social_Network::find($user_id);
        //dd($socialNetworks);

        return view('profils.edit', compact('socialNetworks'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    public function facebookupdate(Request $request){

        $this->validate($request, [
            'facebook' => 'required',
        ]);

        $user_id = auth()->user()->id;
        $socialNetworks = Social_Network::find($user_id);

        $socialNetworks->facebook = $request->input('facebook');
        $socialNetworks->save();

        return redirect()->route('myprofil')
        ->with('success',
         'Lien facebook modifie avec succes.');

    }

    public function twitterupdate(Request $request){

        $this->validate($request, [
            'twitter' => 'required',
        ]);

        $user_id = auth()->user()->id;
        $socialNetworks = Social_Network::find($user_id);

        $socialNetworks->twitter = $request->input('twitter');
        $socialNetworks->save();

        return redirect()->route('myprofil')
        ->with('success',
         'Lien twitter modifie avec succes.');

    }

    public function instagramupdate(Request $request){

        $this->validate($request, [
            'instagram' => 'required',
        ]);

        $user_id = auth()->user()->id;
        $socialNetworks = Social_Network::find($user_id);

        $socialNetworks->instagram = $request->input('instagram');
        $socialNetworks->save();

        return redirect()->route('myprofil')
        ->with('success',
         'Lien instagram modifie avec succes.');

    }

    public function linkdinkupdate(Request $request){

        $this->validate($request, [
            'linkdink' => 'required',
        ]);

        $user_id = auth()->user()->id;
        $socialNetworks = Social_Network::find($user_id);

        $socialNetworks->linkdink = $request->input('linkdink');
        $socialNetworks->save();

        return redirect()->route('myprofil')
        ->with('success',
         'Lien linkdink modifie avec succes.');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy()
    {
        $user_id = auth()->user()->id;
        $user = User::find($user_id);

        if (($user->profilImage) || ($user->profilImage != 'avatar.jpg')) {
            Storage::delete('public/upload/'.$user->profilImage);
        }

        if (($user->coverImage) || ($user->coverImage != 'avatar.jpg')) {
            Storage::delete('public/upload/'.$user->coverImage);
        }
        $user->delete();

        return redirect()->route('myprofil')
            ->with('success',
             'Utilisateur supprimé avec succès.');
    }

    public function storeImage($image) {
        // Get filename with the extension
        $fileNameWithExt = $image->getClientOriginalName();

        // Get just filename
        $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

        // Get just ext
        $extension = $image->getClientOriginalExtension();

        // Filename to store
        $fileNameToStore = $filename.'_'.time().'.'.$extension;

        // Upload Image
        $path = $image->storeAs('public/upload', $fileNameToStore);
       // $image->move('public/upload', $fileNameToStore);

        return $fileNameToStore;
    }
}
