<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\User;
use App\Social_Network;
use Auth;

//Importing laravel-permission models
use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;
use Illuminate\Support\Facades\Storage;

//Enables us to output flash messaging
use Session;

class UserController extends Controller
{

    public function __construct() {
        $this->middleware(['auth', 'supAdmin']); //supAdmin middleware lets only users with a //specific permission permission to access these resources
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all users and pass it to the view
        $users = User::all();
        return view('users.index')->with('users', $users);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //Get all roles and pass it to the view
        $roles = Role::get();
        return view('users.create', ['roles'=>$roles]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:12|confirmed',
        ]);

        $user = new User();
        $user->name = $request->input('name');
        $user->firstname = $request->input('firstname');
        $user->email = $request->input('email');
        $user->password = $request->input('password');
        $user->profilImage = 'profilDefaultImage.png';
        $user->coverImage = 'coverDefaultImage.jpg';



        $roles = $request['roles']; //Retrieving the roles field
        //Checking if a role was selected
        if (isset($roles)) {
            foreach ($roles as $role) {
                $role_r = Role::where('id', '=', $role)->firstOrFail();
                $user->assignRole($role_r); //Assigning role to user
                $user->roleId = $role;
            }
        } else{
                $role_r = Role::where('id', '=', 2)->firstOrFail();
                $user->assignRole($role_r); //Assigning role member to user
                $user->roleId = 2;
        }

        $user->save();

        $user = User::OrderBy('created_at','desc')->first();

        Social_Network::create([
            'userId' => $user->id,
        ]);

        //Redirect to the users.index view and display message
        return redirect()->route('userslist')
            ->with('success',
             'Utilisateur ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $user = User::findOrFail(decrypt($id));
        $socialNetworks = Social_Network::findOrFail(decrypt($id));

        return view('users.show', compact('user', 'socialNetworks'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = User::findOrFail(decrypt($id)); //Get user with specified id
        $roles = Role::get(); //Get all roles

        return view('users.edit', compact('user', 'roles')); //pass user and roles data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $user = User::findOrFail(decrypt($id)); //Get role specified by id

        $roles = $request['roles']; //Retreive all roles

        if (isset($roles)) {
            $user->roles()->sync($roles);  //If one or more role is selected associate user to roles
        } else {
            $user->roles()->detach(); //If no role is selected remove exisiting role associated to a user
            $user->roleId = 0;
        }

        return redirect()->route('userslist')
            ->with('success',
             'Utilisateur edité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //Find a user with a given id and delete
        $user = User::findOrFail(decrypt($id));
        if (($user->profilImage) || ($user->profilImage != 'avatar.jpg')) {
            Storage::delete('public/upload/'.$user->profilImage);
        }

        if (($user->coverImage) || ($user->coverImage != 'avatar.jpg')) {
            Storage::delete('public/upload/'.$user->coverImage);
        }
        $user->delete();

        return redirect()->route('userslist')
            ->with('success',
             'Utilisateur supprimé avec succès.');
    }
}
